@@ -312,6 +312,8 @@ def corr(dataf, **kwargs):
 @click.argument('arg2', callback=clk.is_file)
 @click.argument('outpref')
 @click.argument('coef', callback=clk.is_file)
+@click.option('-weightlimit', default=0.0,
+              help='minimum probability to include in calculation')
 @click.option('-baselinei', type=int, default=0,
               help='use i as baseline for KDE of all columns')
 @click.option('--relative/--absolute', default=True)
@@ -327,6 +329,9 @@ def logist_error(ctx, arg1, arg2, outpref, coef, **kwargs):
         try:
             aS = np.loadtxt(arg1)
             a2S = np.loadtxt(arg2)
+            if len(a2S.shape) == 1:
+                a2S = a2S.reshape(-1, 1)
+                print(a2S.shape)
             coefs = np.loadtxt(coef)
             labels = aS[:,0]
             if kwargs['rng'] is None:
@@ -337,7 +342,7 @@ def logist_error(ctx, arg1, arg2, outpref, coef, **kwargs):
                 rdif = get_rdif(aS, a2S, i, relative=kwargs['relative'])
                 adif = np.abs(rdif)
                 print('\n',i)
-                out = hs.error_lgw(aS[:,kwargs['baselinei']], adif, rdif, coefs)
+                out = hs.error_lgw(aS[:,kwargs['baselinei']], adif, rdif, coefs, aS[:,i], t=kwargs['weightlimit'])
                 outf = f'{outpref}_{i}.txt'
                 np.savetxt(outf, out)
         except click.Abort:
@@ -355,6 +360,7 @@ def logist_error(ctx, arg1, arg2, outpref, coef, **kwargs):
               help='column of training y vals')
 @click.option('-rng', default=None, callback=clk.split_float,
               help='if none, returns values from dataf (required if coef)')
+@click.option('-weights', default=None, callback=clk.split_float)
 @click.option('--sort/--no-sort', default=False)
 @click.option('-outc', default=None,
               help='if given, save coefs to file')
@@ -371,10 +377,14 @@ def softmax(ctx, coef, **kwargs):
             if coefs.size != 6:
                 x = coefs[:,kwargs['x']]
                 y = coefs[:,kwargs['y']]
-                w = {0:1,1:len(x[y == 0])/len(y[y != 0]),2:len(y[y == 0])/len(y[y != 0])}
+                if kwargs['weights'] is None:
+                    w = 'balanced'
+                else:
+                    w = dict(enumerate(kwargs['weights']))
+                # w = {0:1,1:len(x[y == 0])/len(y[y != 0]),2:len(y[y == 0])/len(y[y != 0])}
                 coefs = hs.train_logit(x, y, w)
-                if outc is not None:
-                    np.savetxt(out, coefs)
+                if kwargs['outc'] is not None:
+                    np.savetxt(kwargs['outc'], coefs)
             if kwargs['rng'] is None:
                 rng = x
             else:
